@@ -1,7 +1,7 @@
 #' Learner for conducting Optimal Feature Selection on classification problems
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.0.0/OptimalFeatureSelection/reference/#IAI.OptimalFeatureSelectionClassifier}{\code{IAI.OptimalFeatureSelectionClassifier}}
+#' \href{https://docs.interpretable.ai/v2.1.0/OptimalFeatureSelection/reference/#IAI.OptimalFeatureSelectionClassifier}{\code{IAI.OptimalFeatureSelectionClassifier}}
 #'
 #' @usage optimal_feature_selection_classifier(...)
 #'
@@ -23,7 +23,7 @@ optimal_feature_selection_classifier <- function(...) {
 #' Learner for conducting Optimal Feature Selection on regression problems
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.0.0/OptimalFeatureSelection/reference/#IAI.OptimalFeatureSelectionRegressor}{\code{IAI.OptimalFeatureSelectionRegressor}}
+#' \href{https://docs.interpretable.ai/v2.1.0/OptimalFeatureSelection/reference/#IAI.OptimalFeatureSelectionRegressor}{\code{IAI.OptimalFeatureSelectionRegressor}}
 #'
 #' @usage optimal_feature_selection_regressor(...)
 #'
@@ -45,11 +45,13 @@ optimal_feature_selection_regressor <- function(...) {
 #' Return the constant term in the prediction in the trained learner
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.0.0/OptimalFeatureSelection/reference/#IAI.get_prediction_constant}{\code{IAI.get_prediction_constant}}
+#' \href{https://docs.interpretable.ai/v2.1.0/OptimalFeatureSelection/reference/#IAI.get_prediction_constant}{\code{IAI.get_prediction_constant}}
 #'
-#' @usage get_prediction_constant(lnr)
+#' @usage get_prediction_constant(lnr, ...)
 #'
 #' @param lnr The learner to query.
+#' @param ... If a GLMNet learner, the index of the fit in the path to query,
+#'            defaulting to the best fit if not supplied.
 #'
 #' @examples \dontrun{iai::get_prediction_constant(lnr)}
 #'
@@ -57,9 +59,9 @@ optimal_feature_selection_regressor <- function(...) {
 #' Requires IAI version 1.1 or higher.
 #'
 #' @export
-get_prediction_constant <- function(lnr) {
+get_prediction_constant <- function(lnr, ...) {
   requires_iai_version("1.1.0", "get_prediction_constant")
-  jl_func("IAI.get_prediction_constant_convert", lnr)
+  jl_func("IAI.get_prediction_constant_convert", lnr, ...)
 }
 
 
@@ -67,11 +69,13 @@ get_prediction_constant <- function(lnr) {
 #' the trained learner
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.0.0/OptimalFeatureSelection/reference/#IAI.get_prediction_weights}{\code{IAI.get_prediction_weights}}
+#' \href{https://docs.interpretable.ai/v2.1.0/OptimalFeatureSelection/reference/#IAI.get_prediction_weights}{\code{IAI.get_prediction_weights}}
 #'
-#' @usage get_prediction_weights(lnr)
+#' @usage get_prediction_weights(lnr, ...)
 #'
 #' @param lnr The learner to query.
+#' @param ... If a GLMNet learner, the index of the fit in the path to query,
+#'            defaulting to the best fit if not supplied.
 #'
 #' @examples \dontrun{iai::get_prediction_weights(lnr)}
 #'
@@ -79,9 +83,9 @@ get_prediction_constant <- function(lnr) {
 #' Requires IAI version 1.1 or higher.
 #'
 #' @export
-get_prediction_weights <- function(lnr) {
+get_prediction_weights <- function(lnr, ...) {
   requires_iai_version("1.1.0", "get_prediction_weights")
-  out <- jl_func("IAI.get_prediction_weights_convert", lnr)
+  out <- jl_func("IAI.get_prediction_weights_convert", lnr, ...)
   names(out) <- c("numeric", "categoric")
   out
 }
